@@ -1,3 +1,4 @@
+#define STRICT_R_HEADERS
 #include <Rcpp.h>
 using namespace Rcpp;
 
@@ -41,7 +42,7 @@ double compute_groupcond_logl(NumericMatrix x,
   int wn = dims[3];
   
   // constants
-  double sqrtpi = std::sqrt(2*PI);
+  double sqrtpi = std::sqrt(2*M_PI);
   double cz = std::pow(sqrtpi, zn);
   double cw = std::pow(sqrtpi, wn);
   
